@@ -6,7 +6,7 @@
 #
 
 package Range::Merge v0.01.00;
-$Range::Merge::VERSION = '1.001';
+$Range::Merge::VERSION = '1.002';
 use Range::Merge::Boilerplate 'script';
 
 require Exporter;
@@ -211,7 +211,7 @@ Range::Merge - Merges ranges of data including subset/superset ranges
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
@@ -231,6 +231,24 @@ IP addresses are one example of this type of data - many variations
 exist.  Because IP addresses can be represented as integers, it is possible
 to write a generic range merging alogirthm that operates on integers.
 
+=head1 FUNCTIONS
+
+=head2 merge($ranges)
+
+This is the soul of the C<Range::Merge> module - it merges an array
+reference of ranges (passed in as the sole argument).  The output is
+an array reference of the merged ranges.
+
+=head2 merge_ipv4($cidr)
+
+This is functionally similar to the C<merge> function, except for the
+type of input it takes. The C<$cidr> parameter must consist of an
+array reference of array references.  Each of the child array references
+reference of ranges (passed in as the sole argument).  The output is
+an array reference of the merged ranges.
+
+The output is then turned back into CIDRs.
+
 =head1 RANGE DATA DEFINITION
 
 Range data is defined as two integers, a start and an end, along with
@@ -274,22 +292,6 @@ there is an IP address (IPv4 only at this point).  For example:
 
 This form is used by the C<merge_ipv4()> function.
 
-=function merge($ranges)
-
-This is the soul of the C<Range::Merge> module - it merges an array
-reference of ranges (passed in as the sole argument).  The output is
-an array reference of the merged ranges.
-
-=function merge_ipv4($cidr)
-
-This is functionally similar to the C<merge> function, except for the
-type of input it takes. The C<$cidr> parameter must consist of an
-array reference of array references.  Each of the child array references
-reference of ranges (passed in as the sole argument).  The output is
-an array reference of the merged ranges.
-
-The output is then turned back into CIDRs.
-
 =head1 AUTHOR
 
 Joel Maslak <jmaslak@antelope.net>
